Index: /BAORadio/libindi/libindi/BAOTest/BAOtest_main.cpp
===================================================================
--- /BAORadio/libindi/libindi/BAOTest/BAOtest_main.cpp	(revision 497)
+++ /BAORadio/libindi/libindi/BAOTest/BAOtest_main.cpp	(revision 498)
@@ -75,7 +75,7 @@
         result.y=atoi(str.substr(7, 4).c_str());
 
-        if (str[1]=='b') result.x=-result.x;
-
-        if (str[6]=='b') result.y=-result.y;
+        if (str[1]=='f') result.x=-result.x;
+
+        if (str[6]=='f') result.y=-result.y;
     }
 
@@ -193,15 +193,15 @@
          
 
-			if (asks.find("p")!=string::npos)
+			if (asks.find("P")!=string::npos)
                         {
 
                            strcpy(chaine,"ACK/POSITION\n");
                            client_socket << chaine;
-
+//usleep(10000);
                             if (Affichage) std::cout <<  "MicrocontroÌleur : " << chaine;
 
                             if (Aleat)
                             {
-                                sprintf(chaine, "POSITION/%i/%i/\n", Pos.x, Pos.y);
+                                sprintf(chaine, "POSITION/%04i/%04i/\n", Pos.x, Pos.y);
                             }
                             else
@@ -211,6 +211,7 @@
                         }
 
-                        if (asks.find("g")!=string::npos)
-                        {
+                        if (asks.find("G")!=string::npos)
+                        {
+			
                             Pos2=ExtractPosition2(asks);
 			    
@@ -240,5 +241,5 @@
                         }
 
-                        if (asks.find("z")!=string::npos)
+                        if (asks.find("Z")!=string::npos)
                         {
 
@@ -258,5 +259,5 @@
                         }
 
-                        if (asks.find("a")!=string::npos)
+                        if (asks.find("A")!=string::npos)
                         {
 
Index: /BAORadio/libindi/libindi/drivers/telescope/BAO.h
===================================================================
--- /BAORadio/libindi/libindi/drivers/telescope/BAO.h	(revision 497)
+++ /BAORadio/libindi/libindi/drivers/telescope/BAO.h	(revision 498)
@@ -30,7 +30,7 @@
 #define MAXCARACTERES 1024
 
-#define MAXATTENTE 40                //Si une commande ne recoit pas d'acknowledge. Alors refaire 40 tentatives en renvoyant la commande
+#define MAXATTENTE 80                //Si une commande ne recoit pas d'acknowledge. Alors refaire 80 tentatives en renvoyant la commande
 #define MAXANOMALIES 2               //Si pas de rÃ©ponse au bout de 80 tentatives -> erreur critique -> socket perdu ?
-#define MAXANOMALIESGOTO 1000
+#define MAXANOMALIESGOTO 1500
 
 struct Position

Index: /BAORadio/libindi/libindi/drivers/telescope/BAO.cpp
===================================================================
--- /BAORadio/libindi/libindi/drivers/telescope/BAO.cpp	(revision 497)
+++ /BAORadio/libindi/libindi/drivers/telescope/BAO.cpp	(revision 498)
@@ -815,9 +815,9 @@
     
     // Le calcul est ici trÃšs sommaire et arbitraire :
     // Je considÃšre qu'il y a 6000 positions possibles sur les deux axes
     // De plus, je considÃšre qu'il n'est pas possible de viser un objet Ã 
     // moins de 30Â° de hauteur au-dessus de l'horizon
     
-    TargetPosition.x=(int)(targetAz*6000.0/360.0);
+    TargetPosition.x=(int)(targetAz*100.0/360.0);
     
     targetAlt=((90.0-targetAlt)/60.0);
@@ -826,5 +826,5 @@
       //au-dessus de l'horizon
       
-      TargetPosition.y=(int)(6000.0*targetAlt);
+      TargetPosition.y=(int)(100.0*targetAlt);
   }
   
@@ -1654,11 +1654,4 @@
   }
   
-  /**************************************************************************************
-  ** Commande STATUS
-  ***************************************************************************************/
-  bool BAO::STATUS(int numsocket)
-  {
-    return COMMANDE(numsocket, (char*)"s", (char*)"");
-  }
   
   /**************************************************************************************
@@ -1668,5 +1661,5 @@
   bool BAO::POSITION(int numsocket)
   {
-    return COMMANDE(numsocket, (char*)"p", (char*)"");
+    return COMMANDE(numsocket, (char*)"P", (char*)"");
   }
   
@@ -1677,5 +1670,5 @@
   bool BAO::PARK(int numsocket)
   {
-    return COMMANDE(numsocket, (char*)"z", (char*)"");
+    return COMMANDE(numsocket, (char*)"Z", (char*)"");
   }
   
@@ -1686,5 +1679,5 @@
   bool BAO::ABORT(int numsocket)
   {
-    return COMMANDE(numsocket, (char*)"a", (char*)"");
+    return COMMANDE(numsocket, (char*)"A", (char*)"");
   }
   
@@ -1700,11 +1693,11 @@
     char sensAlt;
     
-    sensAlt='f';
-    sensAz='f';
+    sensAlt='b';
+    sensAz='b';
     
     if (deltaAz<0)
     {
       deltaAz=-deltaAz;
-      sensAz='b';
+      sensAz='f';
     }
     
@@ -1712,12 +1705,12 @@
     {
       deltaAlt=-deltaAlt;
-      sensAlt='b';
+      sensAlt='f';
     }
     
     sprintf(Params, "%c%04i%c%04i", sensAz, deltaAz, sensAlt, deltaAlt);
     
-    return COMMANDE(numsocket, (char*)"g", Params);
-  }
-  
-  
-  
+    return COMMANDE(numsocket, (char*)"G", Params);
+  }
+  
+  
+  
@@ -815,9 +815,9 @@
     
     // Le calcul est ici trÃšs sommaire et arbitraire :
-    // Je considÃšre qu'il y a 6000 positions possibles sur les deux axes
+    // Je considÃšre qu'il y a 100 positions possibles sur les deux axes
     // De plus, je considÃšre qu'il n'est pas possible de viser un objet Ã 
     // moins de 30Â° de hauteur au-dessus de l'horizon